# espiownage
> Utterly dominating ESPI image inference


This file will become your README and also the index of your documentation.

## Install

`pip install espiownage`

## How to use

### ellipse editor

```bash
$ ellipse_editor --files=*.csv
```
